export function getTypedArray(dataview, metadata) {
    switch (metadata.dtype) {
        case 'int8':
            return new Int8Array(dataview.buffer);
            break;
        case 'uint8':
            return new Uint8Array(dataview.buffer);
            break;
        case 'int16':
            return new Int16Array(dataview.buffer);
            break;
        case 'uint16':
            return new Uint16Array(dataview.buffer);
            break;
        case 'int32':
            return new Int32Array(dataview.buffer);
            break;
        case 'uint32':
            return new Uint32Array(dataview.buffer);
            break;
        case 'float32':
            return new Float32Array(dataview.buffer);
            break;
        case 'float64':
            return new Float64Array(dataview.buffer);
            break;
        default:
            throw 'Unknown dtype ' + metadata.dtype;
            break;
    }
}
var Scalar;
(function (Scalar) {
    function isScalar(x) {
        return (x === null ||
            typeof x === 'boolean' ||
            typeof x === 'number' ||
            typeof x === 'string');
    }
    Scalar.isScalar = isScalar;
})(Scalar || (Scalar = {}));
// Buffered argument
export class Arg {
}
class ScalarArg extends Arg {
    constructor(value) {
        super();
        this.value = value;
        this.length = Infinity;
    }
    getItem(idx) {
        return this.value;
    }
}
class BufferArg extends Arg {
    constructor(bufferMetadata, buffer) {
        super();
        this.value = getTypedArray(buffer, bufferMetadata);
        this.length = this.value.length;
    }
    getItem(idx) {
        return this.value[idx];
    }
}
export function getArg(metadata, buffers) {
    if (Scalar.isScalar(metadata)) {
        return new ScalarArg(metadata);
    }
    if (metadata['idx'] !== undefined) {
        return new BufferArg(metadata, buffers[metadata['idx']]);
    }
    throw 'Could not process argument ' + metadata;
}
export async function toBlob(canvas) {
    return new Promise((resolve, reject) => {
        canvas.toBlob(blob => {
            if (blob == null) {
                return reject('Unable to create blob');
            }
            resolve(blob);
        });
    });
}
export async function toBytes(canvas) {
    const blob = await toBlob(canvas);
    return new Promise((resolve, reject) => {
        const reader = new FileReader();
        reader.onloadend = () => {
            if (typeof reader.result == 'string' || reader.result == null) {
                return reject('Unable to read blob');
            }
            const bytes = new Uint8ClampedArray(reader.result);
            resolve(bytes);
        };
        reader.readAsArrayBuffer(blob);
    });
}
export async function fromBytes(array) {
    const blob = new Blob([array]);
    return new Promise((resolve, reject) => {
        const img = new Image();
        img.onload = () => {
            resolve(img);
        };
        img.src = URL.createObjectURL(blob);
    });
}
export async function bufferToImage(buffer) {
    let url;
    const blob = new Blob([buffer], { type: 'image/jpeg' });
    url = URL.createObjectURL(blob);
    const img = new Image();
    return new Promise(resolve => {
        img.onload = () => {
            resolve(img);
        };
        img.src = url;
    });
}
//# sourceMappingURL=utils.js.map